Strongly-typed identifiers for feeds, tracks, detections, and stages.
All IDs are lightweight, Copy, and suitable for use as hash-map keys.
Structs
- Detection
Id - Unique identifier for a single detection within a frame.
- FeedId
- Unique identifier for a video feed within the runtime.
- StageId
- Identifier for a perception stage.
- TrackId
- Unique identifier for a tracked object across frames.